@@ -4,26 +4,26 @@
     License: GPL or LGPL (at your choice)
     WWW: http://www.linux-games.com/sfont/
 
-    This program is free software; you can redistribute it and/or modify        
-    it under the terms of the GNU General Public License as published by        
-    the Free Software Foundation; either version 2 of the License, or           
-    (at your option) any later version.                                         
-                                                                                
-    This program is distributed in the hope that it will be useful,       
-    but WITHOUT ANY WARRANTY; without even the implied warranty of              
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               
-    GNU General Public License for more details.                
-                                                                               
-    You should have received a copy of the GNU General Public License           
-    along with this program; if not, write to the Free Software                 
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA   
-                                                                                
+    This program is free software; you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or
+    (at your option) any later version.
+
+    This program is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
+
+    You should have received a copy of the GNU General Public License
+    along with this program; if not, write to the Free Software
+    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
     Karl Bartel
-    Cecilienstr. 14                                                    
+    Cecilienstr. 14
     12307 Berlin
     GERMANY
-    karlb@gmx.net                                                      
-*/                                                                            
+    karlb@gmx.net
+*/
 #include <SDL.h>
 
 #include <assert.h>
@@ -37,11 +37,11 @@ static Uint32 GetPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y)
 
    assert(X>=0);
    assert(X<Surface->w);
-   
+
    Bpp = Surface->format->BytesPerPixel;
    bits = ((Uint8 *)Surface->pixels)+Y*Surface->pitch+X*Bpp;
 
-   // Get the pixel
+   /* Get the pixel */
    switch(Bpp) {
       case 1:
          return *((Uint8 *)Surface->pixels + Y * Surface->pitch + X);
@@ -49,7 +49,7 @@ static Uint32 GetPixel(SDL_Surface *Surface, Sint32 X, Sint32 Y)
       case 2:
          return *((Uint16 *)Surface->pixels + Y * Surface->pitch/2 + X);
          break;
-      case 3: { // Format/endian independent 
+      case 3: { /* Format/endian independent */
          Uint8 r, g, b;
          r = *((bits)+Surface->format->Rshift/8);
          g = *((bits)+Surface->format->Gshift/8);
@@ -82,7 +82,7 @@ SFont_Font* SFont_InitFont(SDL_Surface* Surface)
 
     pink = SDL_MapRGB(Surface->format, 255, 0, 255);
     while (x < Surface->w) {
-	if (GetPixel(Surface, x, 0) == pink) { 
+	if (GetPixel(Surface, x, 0) == pink) {
     	    Font->CharPos[i++]=x;
     	    while((x < Surface->w) && (GetPixel(Surface, x, 0)== pink))
 		x++;
@@ -91,7 +91,7 @@ SFont_Font* SFont_InitFont(SDL_Surface* Surface)
 	x++;
     }
     Font->MaxPos = x-1;
-    
+
     pixel = GetPixel(Surface, 0, Surface->h-1);
     SDL_UnlockSurface(Surface);
     SDL_SetColorKey(Surface, SDL_SRCCOLORKEY, pixel);
@@ -101,7 +101,7 @@ SFont_Font* SFont_InitFont(SDL_Surface* Surface)
 
 void SFont_FreeFont(SFont_Font* FontInfo)
 {
-    // FIXME we free the surface ourselves SDL_FreeSurface(FontInfo->Surface);
+    /* FIXME we free the surface ourselves SDL_FreeSurface(FontInfo->Surface); */
     free(FontInfo);
 }
 
@@ -115,27 +115,27 @@ void SFont_Write(SDL_Surface *Surface, const SFont_Font *Font,
     if(text == NULL)
 	return;
 
-    // these values won't change in the loop
+    /* these values won't change in the loop */
     srcrect.y = 1;
     dstrect.y = y;
     srcrect.h = dstrect.h = Font->Surface->h - 1;
 
     for(c = text; *c != '\0' && x <= Surface->w ; c++) {
 	charoffset = ((int) (*c - 33)) * 2 + 1;
-	// skip spaces and nonprintable characters
+	/* skip spaces and nonprintable characters */
 	if (*c == ' ' || charoffset < 0 || charoffset > Font->MaxPos) {
 	    x += Font->CharPos[2]-Font->CharPos[1];
 	    continue;
 	}
 
-	srcrect.w = dstrect.w = 
+	srcrect.w = dstrect.w =
 	    (Font->CharPos[charoffset+2] + Font->CharPos[charoffset+1])/2 -
 	    (Font->CharPos[charoffset] + Font->CharPos[charoffset-1])/2;
 	srcrect.x = (Font->CharPos[charoffset]+Font->CharPos[charoffset-1])/2;
 	dstrect.x = x - (float)(Font->CharPos[charoffset]
 			      - Font->CharPos[charoffset-1])/2;
 
-	SDL_BlitSurface(Font->Surface, &srcrect, Surface, &dstrect); 
+	SDL_BlitSurface(Font->Surface, &srcrect, Surface, &dstrect);
 
 	x += Font->CharPos[charoffset+1] - Font->CharPos[charoffset];
     }
@@ -152,12 +152,12 @@ int SFont_TextWidth(const SFont_Font *Font, const char *text)
 
     for(c = text; *c != '\0'; c++) {
 	charoffset = ((int) *c - 33) * 2 + 1;
-	// skip spaces and nonprintable characters
+	/* skip spaces and nonprintable characters */
         if (*c == ' ' || charoffset < 0 || charoffset > Font->MaxPos) {
             width += Font->CharPos[2]-Font->CharPos[1];
 	    continue;
 	}
-	
+
 	width += Font->CharPos[charoffset+1] - Font->CharPos[charoffset];
     }
 
