@@ -1,22 +1,26 @@
 /***************************************************************************
-                          const.h - Few defaults can be found here
-                             -------------------
-    begin                : 03.11.2005
-    copyright            : (C) 2005 by Christoph Brill
-    email                : egore@gmx.de
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-/*
-  $Id: const.h,v 1.1 2005/11/03 12:21:56 egore Exp $
-*/
+
+#ifndef TUXFOOTBALL_CONST
+#define TUXFOOTBALL_CONST
 
 #include <vector>
 #include <string>
@@ -26,3 +30,6 @@ const std::string data_dir[] = { (std::string(PACKAGE_DATA_DIR)+"/tuxfootball").
 #else
 const std::string data_dir[] = { "./data", "/usr/local/share/tuxfootball" };
 #endif
+const int data_dirs = sizeof(data_dir)/sizeof(std::string);
+
+#endif
