@@ -1,27 +1,36 @@
 /***************************************************************************
-                          controller.cpp  - Player and CPU control.
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "controller.h"
+
+#include <math.h>
+#include <iostream>
+
 #include "player.h"
 #include "gameengine.h"
 
-#include "math.h"
-#include <iostream>
-
 Controller::Controller(Team *team, Team *opponents, SDLKey up, SDLKey down, SDLKey left, SDLKey right, SDLKey shoot, SDLKey pass, bool isCPU, Ball *ball, Pitch *pitch)
 {
 	m_team = team;
@@ -32,9 +41,9 @@ Controller::Controller(Team *team, Team *opponents, SDLKey up, SDLKey down, SDLK
 	m_right = right;
 	m_shoot = shoot;
 	m_pass = pass;
-	m_shootCount=0;
+	m_shootCount = 0;
 	m_canKick = true;
-	m_lastPlayer = NULL;
+	m_lastPlayer = 0;
 	m_isCPU = isCPU;
 	m_ball = ball;
 	m_pitch = pitch;
@@ -97,9 +106,9 @@ void Controller::updateController(Uint8 *keys)
 	//
 	// Apply aftertouch if necessary.
 	//
-	if(m_lastPlayer!=NULL) {
+	if(m_lastPlayer!=0) {
 		if(!m_lastPlayer->applyAftertouch(dir)) {
-			m_lastPlayer = NULL;
+			m_lastPlayer = 0;
 		}
 	}
 	
@@ -162,7 +171,7 @@ void Controller::updateComputer()
 	m_lastPass++;
 	
 	Player *player = m_team->activePlayer();
-	if(player==NULL) return;
+	if(player==0) return;
 	
 	Point3D goalCenter(m_pitch->centerX(),
 				m_team->topHalf() ? m_pitch->bottomBound() : m_pitch->topBound());
