@@ -1,65 +1,68 @@
 /***************************************************************************
-                          gameengine.cpp  - Main game logic and initialisation
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #include <iostream>
+
 #ifdef HAVE_GETTEXT
-#include <libintl.h>
+#include "gettext.h"
 #define _(String) gettext (String)
-#else
-#define _(String) (String)
 #endif
-	
+
 #include "gameengine.h"
-#include "surfacemanager.h"
-#include "fontmanager.h"
-#include "soundmanager.h"
+#include "resources/surfacemanager.h"
+#include "resources/fontmanager.h"
+#include "resources/soundmanager.h"
 #include "Font.hpp"
 #include "controller.h"
 
-#include "menu.h"
-#include "videosettingsmenu.h"
-#include "redefinekeysmenu.h"
-#include "mainmenu.h"
-#include "menuoptionlist.h"
-#include "menubutton.h"
-#include "menukeyselect.h"
-#include "menulabel.h"
+#include "menu/videosettingsmenu.h"
+#include "menu/redefinekeysmenu.h"
+#include "menu/mainmenu.h"
+#include "menu/elements/menuoptionlist.h"
+#include "menu/elements/menubutton.h"
+#include "menu/elements/menukeyselect.h"
+#include "menu/elements/menulabel.h"
 
-#include "mainmenustate.h"
-#include "redefinekeysstate.h"
-#include "matchstartstate.h"
-#include "nationalanthemstate.h"
-#include "firsthalfstate.h"
-#include "halftimestate.h"
-#include "secondhalfstate.h"
-#include "fulltimestate.h"
-#include "extratimestate.h"
-#include "extratimefirsthalfstate.h"
-#include "extratimehalftimestate.h"
-#include "extratimesecondhalfstate.h"
-#include "penaltyshootoutstate.h"
-#include "matchabortedstate.h"
-#include "matchfinishedstate.h"
-#include "videomenustate.h"
+#include "gamestates/mainmenustate.h"
+#include "gamestates/redefinekeysstate.h"
+#include "gamestates/matchstartstate.h"
+#include "gamestates/nationalanthemstate.h"
+#include "gamestates/firsthalfstate.h"
+#include "gamestates/halftimestate.h"
+#include "gamestates/secondhalfstate.h"
+#include "gamestates/fulltimestate.h"
+#include "gamestates/extratimestate.h"
+#include "gamestates/extratimefirsthalfstate.h"
+#include "gamestates/extratimehalftimestate.h"
+#include "gamestates/extratimesecondhalfstate.h"
+#include "gamestates/penaltyshootoutstate.h"
+#include "gamestates/matchabortedstate.h"
+#include "gamestates/matchfinishedstate.h"
+#include "gamestates/videomenustate.h"
 #include "const.h"
+#include "logger/logger.h"
 
 Player *GameEngine::s_lastTouch=0;
 
@@ -93,7 +96,7 @@ GameEngine::GameEngine(bool fullscreen) :
 
 	// Start audio.
 	if(Mix_OpenAudio(44100, MIX_DEFAULT_FORMAT, 2, 1024)==-1) {
-		std::cout << "Warning - audio failed to start : " << Mix_GetError() << std::endl;
+		WARN("audio failed to start : " << Mix_GetError());
 		m_audioOpen = false;
 	} else {
 		m_audioOpen = true;
@@ -108,34 +111,32 @@ GameEngine::GameEngine(bool fullscreen) :
 	m_sounds.push_back(SoundManager::instance()->load("sound/crowdooh.wav"));
 
 	m_quitKey = SDLK_ESCAPE;
-	
+
 	m_resX = 800;
 	m_resY = 600;
 
 	uint sdl_flags = SDL_SWSURFACE;
 	if (m_fullscreen) sdl_flags |= SDL_FULLSCREEN;
-	m_screen = SDL_SetVideoMode(m_resX, m_resY, 16, sdl_flags);
-	#ifdef HAVE_CONFIG_H
+	m_screen = SDL_SetVideoMode(m_resX, m_resY, 32, sdl_flags);
+#ifdef HAVE_CONFIG_H
 	SDL_WM_SetCaption(PACKAGE_STRING, NULL);
-	#else
+#else
 	SDL_WM_SetCaption("tuxfootball", NULL);
-	#endif
-	if ( m_screen == NULL ) {
+#endif
+	if(m_screen == 0) {
 		m_finished = true;
-		std::cerr << "Unable to set " << m_resX << "x" << m_resY << " video: " << SDL_GetError() << std::endl;
-		m_pitch = NULL;
-		m_ball = NULL;
-		m_homeTeam = NULL;
-		m_awayTeam = NULL;
-		m_renderer = NULL;
-		m_nameFont = NULL;
-		m_scoreFont = NULL;
+		ERROR("Unable to set " << m_resX << "x" << m_resY << " video: " << SDL_GetError());
+		m_pitch = 0;
+		m_ball = 0;
+		m_homeTeam = 0;
+		m_awayTeam = 0;
+		m_renderer = 0;
+		m_nameFont = 0;
+		m_scoreFont = 0;
 	} else {
 		// Load Fonts
-		std::string str = "graphics/font_yellow.png";
-		m_nameFont = FontManager::instance()->load(m_screen->format, str, false, true);
-		str = "graphics/font_white.png";
-		m_scoreFont = FontManager::instance()->load(m_screen->format, str, false, true);
+		m_nameFont = FontManager::instance()->load(m_screen->format, "graphics/font_yellow.png", false, true);
+		m_scoreFont = FontManager::instance()->load(m_screen->format, "graphics/font_white.png", false, true);
 
 		// Write out text to show our starting progress
 		m_scoreFont->write(m_screen, _("Starting Renderer"), 10, 10);
@@ -159,7 +160,7 @@ GameEngine::GameEngine(bool fullscreen) :
 		m_awayTeam = new Team(this, "Red City", "RED", "team2", "graphics/awayplayermarker.png", m_pitch, m_ball, false);
 	}
 
-	SDL_Rect r = {m_resX/2, m_resY/2, m_pitch->width()-(m_resX), m_pitch->height()-(m_resY)};
+	SDL_Rect r = {(Sint16)(m_resX/2), (Sint16)(m_resY/2), (Uint16)(m_pitch->width()-(m_resX)), (Uint16)(m_pitch->height()-(m_resY))};
 	m_camera.setBoundingRect(r);
 	r.x = 0;
 	r.y = 0;
@@ -170,8 +171,6 @@ GameEngine::GameEngine(bool fullscreen) :
 	m_homeController = new Controller(m_homeTeam, m_awayTeam, SDLK_UP, SDLK_DOWN, SDLK_LEFT, SDLK_RIGHT, SDLK_LSHIFT, SDLK_LCTRL, false, m_ball, m_pitch);
 	m_awayController = new Controller(m_awayTeam, m_homeTeam, SDLK_k, SDLK_j, SDLK_h, SDLK_l, SDLK_f, SDLK_g, true, m_ball, m_pitch);
 
-	m_menu = 0;
-	m_logo = 0;
 	m_halfLength = 6000;
 
 	m_displayFPS = false;
@@ -194,7 +193,6 @@ GameEngine::GameEngine(bool fullscreen) :
 	m_gameStates.push_back( new MatchAbortedState(*this) );
 	m_gameStates.push_back( new MatchFinishedState(*this) );
 
-	m_score = SurfaceManager::instance()->load(m_screen->format, "graphics/score.png", false, true);
 }
 
 GameEngine::~GameEngine()
@@ -202,13 +200,11 @@ GameEngine::~GameEngine()
 	if(m_pitch) delete m_pitch;
 	if(m_homeTeam) delete m_homeTeam;
 	if(m_awayTeam) delete m_awayTeam;
-	
+
 	if(m_homeController) delete m_homeController;
 	if(m_awayController) delete m_awayController;
 	if(m_renderer) delete m_renderer;
 
-	if(m_score) SurfaceManager::instance()->release(m_score);
-	
 	if(m_nameFont) FontManager::instance()->release(m_nameFont);
 	if(m_scoreFont) FontManager::instance()->release(m_scoreFont);
 
@@ -218,7 +214,7 @@ GameEngine::~GameEngine()
 		if(*it) SoundManager::instance()->release((*it));
 		++it;
 	}
-	
+
 	// Shutdown Audio.
 	Mix_CloseAudio();
 
@@ -233,23 +229,24 @@ void GameEngine::gameLoop()
 {
 	static double totalFPSTime = 0;
 	m_music = 0;
-	
+
 	int nextTime = SDL_GetTicks();
 	m_camera.setPosition(Point3D(m_pitch->width()/2, m_pitch->height()-m_screen->h));
-	
+
 	m_finished = false;
+	// Let's start with the title screen
 	setState(TitleScreen);
 	initialiseMatch();
-	
+
 	do {
 		int startTime = SDL_GetTicks();
 		int currentTime;
 
-		// Make sure we wait for the next frame if we are going too fast... 
+		// Make sure we wait for the next frame if we are going too fast...
 		while( (currentTime = SDL_GetTicks()) < nextTime ) {
 			SDL_Delay(1);
 		}
-	
+
 		// And make sure we catch up if we are going too slow.
 		while(nextTime < currentTime) {
 			iterateEngine();
@@ -272,11 +269,6 @@ void GameEngine::gameLoop()
 void GameEngine::iterateEngine()
 {
 	m_gameStates[m_currentState]->updateLoop();
-	
-	if((m_menu) && (m_menu->finished())) {
-		delete m_menu;
-		m_menu = 0;
-	}
 
 	m_homeTeam->update();
 	m_awayTeam->update();
@@ -297,9 +289,9 @@ void GameEngine::iterateEngine()
 
 	m_camera.update();
 
-	if(m_gameInProgress) {
+	if(isGameInProgress()) {
 		switch(m_subMode) {
-			case InPlay :				
+			case InPlay :
 				if(m_pitch->crossesSideLine(Segment(m_ball->lastPosition(), m_ball->position()))) {
 					setBallPreparedPosition(m_pitch->lastIntersection());
 					setSubMode(ThrowIn, (GameEngine::lastTeamTouch() == m_awayTeam), false, m_pitch->lastIntersection());
@@ -367,123 +359,37 @@ void GameEngine::iterateEngine()
 			case GoalCelebration :
 				setSubMode(KickOff, !m_subModeHome);
 				break;
-		} 
+		}
 	}
 }
 
 void GameEngine::drawFrame()
 {
-	static int x = 0;
-	SDL_Rect r, s, score_pos, score_size;
-	x+=2;
-	
 	int left = (int)m_camera.position().x() - m_resX/2;
 	int top = (int)m_camera.position().y() - m_resY/2;
 
+	// First of all draw the pitch
 	m_pitch->draw(left, top);
 
+	// Now render the players
 	m_renderer->update();
 	m_renderer->draw(left, top);
 
-	if(m_gameInProgress) {
+	// Finally render additional information depending on the gamestate
+	m_gameStates[m_currentState]->renderFrame();
 
-		//
-		// Draw Score background
-		//
-		if(m_score) {
-			score_size.x = 0;
-			score_size.y = 0;
-			score_size.w = 298;
-			score_size.h = 28;
-			score_pos.x = m_screen->w - score_size.w - 10;
-			score_pos.y = 10;
-			score_pos.w = 298;
-			score_pos.h = 28;
-			if(SDL_BlitSurface(m_score, &score_size, m_screen, &score_pos) < 0) {
-				std::cerr << "Error - could not blit score : " << SDL_GetError() << std::endl;
-			}
-		}
-
-		//
-		// Draw Score
-		//
-		std::ostringstream homeScoreStr;
-		std::ostringstream awayScoreStr;
-
-		homeScoreStr << m_homeScore;
-		awayScoreStr << m_awayScore;	
-
-		m_scoreFont->write(m_screen, homeScoreStr.str().c_str(), m_screen->w-228, 12);
-		m_scoreFont->write(m_screen, "-", m_screen->w-207, 12);
-		m_scoreFont->write(m_screen, awayScoreStr.str().c_str(), m_screen->w-193, 12);
-
-		m_nameFont->write(m_screen, m_homeTeam->shortname().c_str(), 
-			  m_screen->w-295, 12);
-		m_nameFont->write(m_screen, m_awayTeam->shortname().c_str(), 
-			  m_screen->w-160, 12);
-
-		
-		int scoreWidth = m_scoreFont->getTextWidth(homeScoreStr.str().c_str());
-		scoreWidth = (scoreWidth < m_scoreFont->getTextWidth(awayScoreStr.str().c_str())) ? scoreWidth : m_scoreFont->getTextWidth(awayScoreStr.str().c_str());
-		scoreWidth += 20;
-
-		int sm = m_screen->w/2;
-
-		m_scoreFont->write(m_screen, homeScoreStr.str().c_str(), sm - scoreWidth, m_screen->h-34);
-		m_scoreFont->write(m_screen, awayScoreStr.str().c_str(), sm + 20, m_screen->h-34);
-	
-		m_nameFont->write(m_screen, m_homeTeam->name().c_str(), 
-			  sm - scoreWidth - m_nameFont->getTextWidth(m_homeTeam->name().c_str())-20, m_screen->h-34);
-		m_nameFont->write(m_screen, m_awayTeam->name().c_str(), 
-			  sm+scoreWidth+20, m_screen->h-34);
-
-		//
-		// Draw Time
-		//
-		std::ostringstream str3;
-		int minutes = ((2700 * m_timer)/m_halfLength)%60;
-	
-		if(minutes<10) {
-			str3 << ((2700 * m_timer)/m_halfLength)/60 << ":0" << ((2700 * m_timer)/m_halfLength)%60;
-		} else {
-			str3 << ((2700 * m_timer)/m_halfLength)/60 << ":" << ((2700 * m_timer)/m_halfLength)%60;
-		}
-		
-		m_scoreFont->write(m_screen, str3.str().c_str(), m_screen->w - m_scoreFont->getTextWidth(str3.str().c_str()) - 22, 12);
-	}
-
-	//
-	// Draw frames per second
-	// 
+	// Optionally draw frames per second
 	if(m_displayFPS) {
 		std::ostringstream str4;
 		str4 << "FPS : " << m_framesPerSecond;
 		m_scoreFont->write(m_screen, str4.str().c_str(), m_screen->w - 10 - m_scoreFont->getTextWidth(str4.str().c_str()), 40);
 	}
 
-	//
-	// Draw Menu
-	//
-	if(m_menu) m_menu->draw();
-	
-	if(m_logo) {
-		s.x = (m_screen->w - m_logo->w) / 2;
-		s.y = 50;
-		r.x = 0;
-		r.y = 0;
-		s.w = r.w = m_logo->w;
-		s.h = r.h = m_logo->h;
-
-		
-		if(SDL_BlitSurface(m_logo, &r, m_screen, &s) < 0) {
-			std::cerr << "Error - could not pitch tile : " << SDL_GetError() << std::endl;
-		}
-	}
-
+	// Now put everything on screen
 	SDL_Flip(m_screen);
 }
 
-bool GameEngine::finished() 
+bool GameEngine::finished()
 {
 	return m_finished;
 }
@@ -492,7 +398,7 @@ bool GameEngine::finished()
 void GameEngine::setTimer(TimerState state)
 {
 	m_timerState = state;
-	
+
 	if(state==Restart) {
 		m_timer = 0;
 		m_timerState = Start;
@@ -511,46 +417,44 @@ uint GameEngine::timer() const
 
 void GameEngine::setState(GameState state)
 {
-	if((m_currentState >= 0) && (m_currentState < m_gameStates.size()))
+	// First leave the current gamestate (if any)
+	if((m_currentState >= 0) && (m_currentState < (int) m_gameStates.size()))
 	{
+		DEBUG("Leaving gamestate " << m_currentState);
 		m_gameStates[m_currentState]->leaveState();
 	}
+	// Now remember the new gamestate and enter it (if any)
 	m_currentState=state;
-	if((m_currentState >= 0) && (m_currentState < m_gameStates.size()))
+	if((m_currentState >= 0) && (m_currentState < (int) m_gameStates.size()))
 	{
+		DEBUG("Entering gamestate " << m_currentState);
 		m_gameStates[m_currentState]->enterState();
 	}
-	
-	if((m_currentState==FirstHalf) || (m_currentState==SecondHalf) ||
-	   (m_currentState==ExtraTimeFirstHalf) || (m_currentState==ExtraTimeSecondHalf)) {
-		m_gameInProgress = true;
-	} else {
-		m_gameInProgress = false;
-	}
 
-	std::cout << "New state is " << m_currentState << std::endl;
 }
 
 void GameEngine::updateKeyboard()
-{	
+{
 	SDL_Event event;
 	static bool quitting = false;
 
-	while(SDL_PollEvent(&event)) {		
+	while(SDL_PollEvent(&event)) {
 		if(event.type == SDL_QUIT) m_finished = 1;
 	}
 
 	Uint8 *keys = SDL_GetKeyState(NULL);
-	
+
 	m_homeController->updateController(keys);
 	m_awayController->updateController(keys);
 
-	if(m_menu) {
-		m_menu->update(keys);
-	}
+	m_gameStates[m_currentState]->update(keys);
 
 	if(keys[m_quitKey]) {
-		quitting = true;
+		if (m_currentState >= 0 && (m_currentState < (int) m_gameStates.size()) && m_currentState == TitleScreen) {
+			m_finished = 1;
+		} else {
+			quitting = true;
+		}
 	} else {
 		if(quitting) {
 			setState(TitleScreen);
@@ -565,25 +469,28 @@ void GameEngine::setSubMode(SubMode mode, bool home, bool left, const Point3D &p
 
 	switch(mode) {
 		case InPlay :
+			DEBUG("Prepare InPlay");
 			m_homeTeam->setControlState(Player::Full);
 			m_awayTeam->setControlState(Player::Full);
 			setTimer(Start);
 			break;
-		case KickOff : 
+		case KickOff :
+			DEBUG("Prepare KickOff");
 			m_homeTeam->setupKickoff(home);
 			m_awayTeam->setupKickoff(!home);
 			setTimer(Stop);
 			setBallPreparedPosition(m_pitch->centerSpot());
 			break;
 		case Corner :
+			DEBUG("Prepare Corner");
 			m_homeTeam->setupCorner(left, home);
 			m_awayTeam->setupCorner(left, !home);
 			setTimer(Stop);
 			setBallPreparedPosition(m_pitch->cornerSpot(left, home ? m_awayTeam->topHalf() : m_homeTeam->topHalf()));
 			playSound(RefWhistleTwice);
 			break;
-		case ThrowIn :		
-			std::cout << "Prepare throwin" << std::endl;
+		case ThrowIn :
+			DEBUG("Prepare ThrowIn");
 			m_homeTeam->setupThrowIn(pos, home);
 			m_awayTeam->setupThrowIn(pos, !home);
 			setTimer(Stop);
@@ -591,21 +498,26 @@ void GameEngine::setSubMode(SubMode mode, bool home, bool left, const Point3D &p
 			playSound(RefWhistleTwice);
 			break;
 		case GoalKick :
-			std::cout << "FIXME : Goal Kicks are always on the floor at present." << std::endl;
+			DEBUG("Prepare GoalKick");
+			WARN("FIXME : Goal Kicks are always on the floor at present.");
 			m_homeTeam->setupGoalKick(home, left, true);
 			m_awayTeam->setupGoalKick(!home, left, true);
 			setTimer(Stop);
 			setBallPreparedPosition(m_pitch->goalKickSpot(left, home ? m_homeTeam->topHalf() : m_awayTeam->topHalf()));
 			playSound(RefWhistleTwice);
-			break;			
+			break;
 		case GoalCelebration :
-			std::cout << "No goal celebration at present, go straight to kick off." << std::endl;
+			DEBUG("Prepare GoalCelebration");
+			WARN("No goal celebration at present, go straight to kick off.");
 			playSound(RefWhistleTwice);
 			break;
+		case Penalty:
+		case FreeKick:
 		default :
-			std::cout << "Warning - setSubMode called for mode as yet unwritten" << std::endl;
+			WARN("Warning - setSubMode called for mode "  << mode << " is yet unwritten ");
+			break;
 	}
-	
+
 	m_subModeHome = home;
 }
 
@@ -615,29 +527,6 @@ void GameEngine::setBallPreparedPosition(Point3D pos)
 	m_ballPreparedPosition = pos;
 }
 
-void GameEngine::setMenu(Menu *menu)
-{
-	if(m_menu) {
-		delete m_menu;
-		m_menu = 0;
-	}
-	m_menu = menu;
-}
-
-void GameEngine::setLogo(std::string logoImage)
-{
-	clearLogo();
-	m_logo = SurfaceManager::instance()->load(m_screen->format, logoImage, false, true);
-}
-
-void GameEngine::clearLogo()
-{
-	if(m_logo) {
-		SurfaceManager::instance()->release(m_logo);
-		m_logo = 0;
-	}
-}
-
 void GameEngine::setMusic(std::string musicFile)
 {
 	if(m_music) {
@@ -645,7 +534,6 @@ void GameEngine::setMusic(std::string musicFile)
 		m_music = 0;
 	}
 	if(m_audioOpen) {
-		int data_dirs = sizeof(data_dir)/sizeof(std::string);
 		for (int i = 0; i < data_dirs; i++) {
 			std::string filename = std::string(data_dir[i]);
 			filename.append("/");
@@ -655,7 +543,7 @@ void GameEngine::setMusic(std::string musicFile)
 		}
 
 		if(m_music == 0) {
-			std::cout << "Warning - could not load Title music : " << Mix_GetError() << std::endl;
+			WARN("could not load Title music : " << Mix_GetError());
 		} else {
 			Mix_PlayMusic(m_music, -1);
 		}
@@ -674,6 +562,7 @@ void GameEngine::setCameraFollows(CameraFollows follows)
 		break;
 	default :
 		m_camera.setTarget(0);
+		break;
 	}
 }
 
@@ -695,14 +584,13 @@ Player *GameEngine::addPlayer(std::string skin, std::string playerMarker, Team *
 	Player *p = new Player(m_renderer, skin, playerMarker, m_pitch, team, m_ball, goalkeeper);
 
 	m_playerList.push_back(PlayerContainer(p));
-	
+
 	return p;
 }
 
 void GameEngine::setHalfLength(uint halfLength)
 {
 	m_halfLength = halfLength;
-	std::cout << "Half Length : " << m_halfLength;
 }
 
 uint GameEngine::halfLength() const
@@ -716,11 +604,6 @@ void GameEngine::setupHalfTime()
 	m_awayTeam->setupHalfTime();
 }
 
-Menu *GameEngine::menu()
-{
-	return m_menu;
-}
-
 bool GameEngine::finished() const
 {
 	return m_finished;
@@ -738,9 +621,9 @@ Controller *GameEngine::controller(ControllerType controller)
 		return m_homeController;
 	case AwayController :
 		return m_awayController;
+	default:
+		return 0;
 	}
-	
-	return 0;
 }
 
 SDL_Surface *GameEngine::screen()
@@ -755,14 +638,15 @@ Team *GameEngine::team(TeamTypes team)
 		return m_homeTeam;
 	case AwayTeam :
 		return m_awayTeam;
+	default:
+		return 0;
 	}
-	return 0;
 }
 
 Mix_Chunk *GameEngine::gameSound(GameSounds sound)
 {
 	Mix_Chunk *result = 0;
-	if((sound>=0) && (sound<= m_sounds.size())) {
+	if((sound>=0) && (sound<= (int) m_sounds.size())) {
 		result = m_sounds[sound];
 	}
 	return result;
@@ -770,7 +654,7 @@ Mix_Chunk *GameEngine::gameSound(GameSounds sound)
 
 void GameEngine::playSound(GameSounds sound)
 {
-	if((sound>=0) && (sound<= m_sounds.size())) {
+	if((sound>=0) && (sound<= (int) m_sounds.size())) {
 		if(m_sounds[sound]) {
 			Mix_PlayChannel(-1, m_sounds[sound], 0);
 		}
@@ -779,15 +663,15 @@ void GameEngine::playSound(GameSounds sound)
 
 uint GameEngine::score(TeamTypes team) const
 {
-	uint result = 0;
 	switch(team)
 	{
 	case HomeTeam :
-		result = m_homeScore;
+		return m_homeScore;
 	case AwayTeam :
-		result = m_awayScore;
+		return m_awayScore;
+	default:
+		return 0;
 	}
-	return result;
 }
 
 void GameEngine::setFullScreen(bool fullscreen)
@@ -802,3 +686,11 @@ bool GameEngine::fullScreen() const
 {
 	return m_fullscreen;
 }
+
+bool GameEngine::isGameInProgress()
+{
+	if(m_currentState >= 0) {
+		return m_gameStates[m_currentState]->isGameInProgress();
+	}
+	return false;
+}
