@@ -1,18 +1,22 @@
 /***************************************************************************
-                          gameengine.cpp  - Main game logic and initialisation
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #ifndef TUXFOOTBALL_GAMEENGINE
@@ -22,21 +26,20 @@
 #define uint unsigned int
 #endif
 
-#include "SDL.h"
-#include "SDL_mixer.h"
-#include "Font.hpp"
+#include <SDL.h>
+#include <SDL_mixer.h>
+#include <string>
+#include <sstream>
+#include <list>
+#include <vector>
 
+#include "Font.hpp"
 #include "ball.h"
 #include "pitch.h"
 #include "team.h"
 #include "camera.h"
 #include "graphics.h"
 
-#include <string>
-#include <sstream>
-#include <list>
-#include <vector>
-
 class Player;
 class Menu;
 class Controller;
@@ -117,13 +120,8 @@ public:
 	void setFinished(bool finished);
 	bool finished() const;
 
-	void setLogo(std::string logoImage);
-
 	SDL_Surface *screen();
 
-	/** clears the logo, if one exists. It is safe to call this when no logo exists. */
-	void clearLogo();
-
 	void setMusic(std::string musicFile);
 	void setupHalfTime();
 
@@ -144,6 +142,7 @@ public:
 	/** Returns the specified controller */
 	Controller *controller(ControllerType controller);
 
+	/* Reset the field and scores to the defaults */
 	void initialiseMatch();
 
 	void setFullScreen(bool fullscreen);
@@ -153,12 +152,10 @@ private: // attributes
 
 	std::vector<StateBase *> m_gameStates;
 
+	/* The current gamestate we are in */
 	GameState m_currentState;
 	SubMode m_subMode;
 	bool m_subModeHome;
-	/** True if we are playing a match, rather than in half time, or penalty shootout.
-	 *  If this is true, we take account of corners and submodes. */
-	bool m_gameInProgress;
 	/** Used for timings such as referee whistle, half length, etc.*/
 	uint m_timer;
 	TimerState m_timerState;
@@ -195,10 +192,6 @@ private: // attributes
 
 	std::list<PlayerContainer> m_playerList;
 
-	Menu *m_menu;
-	SDL_Surface *m_logo;
-	SDL_Surface *m_score;
-
 	/** Returns the team other than the one specified. E.g. if you pass it the home team, it returns the away team */
 	Team *otherTeam(Team *team);
 
@@ -216,6 +209,9 @@ private: // methods
 	bool finished();
 	void updateKeyboard();
 	void setBallPreparedPosition(Point3D pos);
+	/** Returns true if we are playing a match, rather than in half time, or penalty shootout.
+	 *  If this is true, we take account of corners and submodes. */
+	bool isGameInProgress();
 };
 
 #endif /* TUXFOOTBALL_GAMEENGINE */
