@@ -1,30 +1,31 @@
 /***************************************************************************
-                          main.cpp  - Execution starts here.
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
-/*
-  $Id: main.cpp,v 1.3 2005/10/26 19:00:54 egore Exp $
-*/
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#include <config.h>
 #endif
 
 #ifdef HAVE_GETTEXT
-#include <libintl.h>
 #include <locale.h>
+#include "gettext.h"
 #endif
 
 #include <iostream>
@@ -38,6 +39,7 @@
 #endif
 
 #include "gameengine.h"
+#include "logger/logger.h"
 
 void die(const char *fmt, ...)
 {
@@ -49,14 +51,13 @@ void die(const char *fmt, ...)
   exit(1);
 }
 
+/** Execution starts here. */
 int main(int argc, char *argv[])
 {
-#ifdef HAVE_GETTEXT
-	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-	textdomain (GETTEXT_PACKAGE);
+#ifdef PACKAGE_VERSION
+	INFO("Starting Tux Football " << PACKAGE_VERSION);
 #else
-	std::cout << "Gettext support not available due to missing config.h support" << std::endl;
+	INFO("Starting Tux Football");
 #endif
 
 	bool fullscreen = false;
@@ -66,16 +67,31 @@ int main(int argc, char *argv[])
 			switch(argv[i][1]) {
 				default:
 				case 'h':
-					printf("\nTux Football [-switch]\n\nswitch can be:\n\n-h\tprint this help\n-w\trun Tux Football in windowed mode\n\n");
+					printf("\nTux Football [-switch]\n\nswitch can be:\n\n-h\tprint this help\n-w\trun Tux Football in windowed mode (default)\n-w\trun Tux Football in fullscreen mode\n-d\tEnable debug logging\n\n");
 					return 0;
-				break;
 				case 'w':
 					fullscreen = false;
-				break;
+					break;
+				case 'f':
+					fullscreen = true;
+					break;
+				case 'd':
+					Logger::setLevel(Logger::Debug);
+					break;
 			}
 		}
 	}
 
+#ifdef HAVE_GETTEXT
+	INFO("Reading locales from " << LOCALEDIR);
+	// Intialize gettext
+	setlocale (LC_ALL, "");
+	bindtextdomain(PACKAGE_NAME, LOCALEDIR);
+	textdomain(PACKAGE_NAME);
+#else
+	DEBUG("Gettext support not available due to missing config.h support");
+#endif
+
 	if (SDL_Init(SDL_INIT_VIDEO | SDL_INIT_TIMER) == -1)
 		die("Couldn't initialize SDL: %s\n", SDL_GetError());
 	atexit(SDL_Quit);
@@ -88,6 +104,11 @@ int main(int argc, char *argv[])
 }
 
 #ifdef _WIN32
+
+#ifndef _MAX_PATH
+#define _MAX_PATH 2048
+#endif
+
 /* Taken from http://www.flipcode.com/archives/WinMain_Command_Line_Parser.shtml */
 int WINAPI WinMain(HINSTANCE instance, HINSTANCE prev_instance, char* command_line, int show_command)
 {
