@@ -1,35 +1,42 @@
 /***************************************************************************
-                          player.cpp  - Encapsulates a football player, and
-                                        all associated logic.
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "player.h"
+
 #include <string>
 #include <iostream>
 #include <cmath>
 
-#include "player.h"
-#include "surfacemanager.h"
+#include "resources/surfacemanager.h"
 #include "matrix.h"
 #include "rect.h"
-
 #include "ball.h"
 #include "team.h"
 #include "pitch.h"
-
 #include "gameengine.h"
+#include "logger/logger.h"
 
 Point3D Player::dirVal[8] = 	{  	Point3D(0,		1, 		0),
 					Point3D(0.707107, 	0.707107, 	0),
@@ -51,28 +58,29 @@ double Player::moveSlowdown = 0.7;
 double Player::walkDistance = 5000;
 /** Further away than this and the player starts running */
 double Player::runDistance = 20000;
-		
+
 
 Player::Player(Graphics *renderer, std::string skin, std::string playerMarker, Pitch *pitch, Team *team, Ball *ball, bool goalie) :
 	Body(Point3D(512.0, 1024.0, 0.0), Point3D(0.0, 0.0, 0.0), Rect()),
 	m_desiredPosition(Point3D(512.0, 1024.0, 0.0))
-{	
+{
 	m_limpSpeed = 1.5;
 	m_walkSpeed = 2.6;
 	m_runSpeed = 3.5;
-	
+
 	m_pitch = pitch;
 	m_renderer = renderer;
 	m_ball = ball;
 	m_team = team;
-	
+	m_goalie = goalie;
+
 	m_commitTime = 0;
 	m_kickCountdown = 0;
 	m_touchTimer = 0;
 	m_justTurned = false;
 	m_dribbleTimer = 0;
-	
-	loadSpriteSurfaces(skin , playerMarker);
+
+	loadSpriteSurfaces(skin, playerMarker);
 	m_refCount=0;
 
 	m_direction=0;
@@ -81,11 +89,10 @@ Player::Player(Graphics *renderer, std::string skin, std::string playerMarker, P
 
 	SDL_Rect sr = {-32, -54, 0, 0};
 	SDL_Rect sh = {-14, -60, 0, 0};
-	SDL_Rect sa = {-16, -60, 0, 0};	
-	m_object = new SpriteObject(NULL, NULL, NULL, position(), sr, sh, sa);
+	SDL_Rect sa = {-16, -60, 0, 0};
+	m_object = new SpriteObject(0, 0, 0, position(), sr, sh, sa);
 	m_renderer->addSprite(m_object);
 
-	m_goalie = goalie;
 }
 
 Player::~Player()
@@ -115,22 +122,22 @@ void Player::calculateDestintaion()
 }
 
 void Player::calculateMovement()
-{	
+{
 	if(controlState() == Full) {
 		tryTrapBall();
-		
+
 		if(!isActive()) {
 			/* This code controls the movement of players who are not on the ball when the ball
 			 * is in play. Players should move towards their desired position, whilst also acting
 			 * intelligently to e.g. intercept the ball.
 			 */
-			
+
 			if(m_goalie) {
 				moveGoalkeeper();
 			} else {
 				Point3D wantToBe = m_desiredPosition;
 				Point3D curDist = position() - wantToBe;
-			
+
 				if(curDist.length() < m_limpSpeed*m_limpSpeed) {
 					setMove(Stand);
 					setDirection(closestDirection(m_ball->position()));
@@ -138,7 +145,7 @@ void Player::calculateMovement()
 					if((m_move!=Run) && (m_move!=Walk)) {
 						setMove(Run);
 					}
-	
+
 					if(curDist.length() < walkDistance) {
 						setMove(Walk);
 					} else if(curDist.length() > runDistance) {
@@ -161,23 +168,23 @@ void Player::calculateMovement()
 
 void Player::move()
 {
-	accelerate(Point3D(0, 0, Pitch::gravity));	
+	accelerate(Point3D(0, 0, Pitch::gravity));
 	Body::move();
 	if(position().z() < 0) {
 		setPosition(Point3D(position().x(), position().y(), 0.0));
 	}
-	
+
 	if((m_move == Tackle) || (m_move == HeavyTackle) || ((m_move == Header) && (position().z()==0))) {
 		applyFriction(m_pitch->friction());
 		m_pitch->scratchSurface(position());
 	}
-	
+
 	if(isActive()) {
 		m_object->setOverlaySurface(m_active);
 	} else {
-		m_object->setOverlaySurface(NULL);
+		m_object->setOverlaySurface(0);
 	}
-	
+
 	m_object->setPosition(position());
 	m_object->setSurface(getSurface());
 }
@@ -194,20 +201,33 @@ void Player::freeReference() {
 void Player::loadSpriteSurfaces(std::string skin, std::string playerMarker)
 {
 	if(m_renderer && m_renderer->screen()) {
-		m_walk = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/walking", "walking", 40, true, true);
-		m_stand = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/standing", "standing", 1, true, true);
-		m_run = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/running", "running", 40, true, true);
-		m_tackle = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/tackling", "tackling", 25, false, true);
-		m_header = new SpriteSequence(m_renderer->screen()->format, 
-								"graphics/"+skin+"/header", "header", 20, false, true);
+
+		std::string basedir;
+		if(m_goalie) {
+			basedir = "graphics/" + skin + "_goalie";
+		} else {
+			basedir = "graphics/" + skin;
+		}
+
+		m_walk = new SpriteSequence(m_renderer->screen()->format,
+								basedir+"/walking", "walking", 40, true);
+		m_stand = new SpriteSequence(m_renderer->screen()->format,
+								basedir+"/standing", "standing", 1, true);
+		m_run = new SpriteSequence(m_renderer->screen()->format,
+								basedir+"/running", "running", 40, true);
+		m_tackle = new SpriteSequence(m_renderer->screen()->format,
+								basedir+"/tackling", "tackling", 25, false);
+		m_header = new SpriteSequence(m_renderer->screen()->format,
+								basedir+"/header", "header", 20, false);
 		m_active = SurfaceManager::instance()->load(m_renderer->screen()->format, playerMarker, true, false);
 	} else {
-		std::cerr << "Error - cannot load Player Sprite surfaces, problem with renderer" << std::endl;
-		m_walk = m_stand = m_run = m_tackle = NULL;
+		ERROR("cannot load Player Sprite surfaces, problem with renderer");
+		m_walk = 0;
+		m_stand = 0;
+		m_run = 0;
+		m_tackle = 0;
+		m_header = 0;
+		m_active = 0;
 	}
 }
 
@@ -218,15 +238,14 @@ void Player::setDestination(const Point3D &pos)
 
 bool Player::setMove(Moves move, int variable)
 {
-	double k = 0.0;
 	Point3D v;
 	Player *player;
 
 	if(committedToMove()) return false;
-	
+
 	if(move!=m_move) {
 		switch(move) {
-			case Stand: 
+			case Stand:
 				break;
 			case Limp:
 				break;
@@ -250,14 +269,14 @@ bool Player::setMove(Moves move, int variable)
 
 				player = m_team->findPlayerFromPosition(position(), m_direction);
 
-				if(player==NULL) {					
+				if(player==0) {
 					v = dirVal[m_direction]*m_runSpeed * 1.4;
 					v.setZ(2);
 				} else {
-					std::cout << "FIXME : pass code passes to players feet where he is now, not where he is " <<
-						"going to be when the ball reaches him" << std::endl;
+					WARN("FIXME : pass code passes to players feet where he is now, not where he is " <<
+						"going to be when the ball reaches him");
 
-					Point3D aimFor = player->position();					
+					Point3D aimFor = player->position();
 
 					v = m_ball->calculateReqVelocity(2, aimFor);
 
@@ -291,22 +310,22 @@ bool Player::setMove(Moves move, int variable)
 				m_kickCountdown = 50;
 				break;
 			case FallOver:
-				std::cout << "FIXME : case FallOver not handles in setMove" << std::endl;
+				WARN("FIXME : case FallOver not handles in setMove");
 				break;
 		}
 
-		k = moveSpeed(move);
+        double k = moveSpeed(move);
 		if(m_touchTimer!=0) k*= Player::moveSlowdown;
-		
+
 		setVelocity(dirVal[m_direction] * k);
 		if(move==Header) {
 			accelerate(Point3D(0,0, 2.5));
 		}
-		
+
 		m_move = move;
 		resetMove();
 		return true;
-	}	
+	}
 	return false;
 }
 
@@ -315,12 +334,12 @@ void Player::resetMove()
 	switch(m_move) {
 		case Stand: 	m_stand->restartSequence();
 				break;
-		case Limp: 
+		case Limp:
 		case Walk: 	m_walk->restartSequence();
 				break;
 		case Run: 	m_run->restartSequence();
 				break;
-		case Tackle:	
+		case Tackle:
 		case HeavyTackle:
 				m_tackle->restartSequence();
 				break;
@@ -333,7 +352,7 @@ void Player::resetMove()
 				m_run->restartSequence();
 				break;
 		case FallOver:
-				std::cout << "FIXME : case FallOver not handles in resetMove" << std::endl;
+				WARN("FIXME : case FallOver not handles in resetMove");
 				break;
 	}
 }
@@ -343,12 +362,12 @@ void Player::updateMove()
 	switch(m_move) {
 		case Stand: 		m_stand->updateSequence();
 					break;
-		case Limp: 
+		case Limp:
 		case Walk: 		m_walk->updateSequence();
 					break;
 		case Run: 		m_run->updateSequence();
 					break;
-		case Tackle: 	
+		case Tackle:
 		case HeavyTackle:	m_tackle->updateSequence();
 					break;
 		case Header:		m_header->updateSequence();
@@ -358,26 +377,28 @@ void Player::updateMove()
 		case Shoot:		m_run->updateSequence();
 					break;
 		case FallOver:
-					std::cout << "FIXME : case FallOver not handles in updateMove" << std::endl;
+		default:
+					WARN("FIXME : case " << m_move << " not handles in updateMove");
 					break;
 	}
 }
 
 SDL_Surface *Player::getSurface()
 {
-	
+
 	switch(m_move) {
 		case Stand: 		return m_stand->surface(m_direction);
 		case Limp: 		return m_walk->surface(m_direction);
 		case Walk: 		return m_walk->surface(m_direction);
 		case Run: 		return m_run->surface(m_direction);
-		case Tackle: 	
+		case Tackle:
 		case HeavyTackle:	return m_tackle->surface(m_direction);
 		case Header:		return m_header->surface(m_direction);
 		case Pass:		return m_run->surface(m_direction);
 		case Shoot:		return m_run->surface(m_direction);
+		case FallOver: // TODO
 		default: 		return m_stand->surface(m_direction);
-	}	
+	}
 }
 
 bool Player::inPosition()
@@ -392,12 +413,12 @@ bool Player::inPosition()
 void Player::setDirection(int direction)
 {
 	if((direction < 0) || (direction > 7)) {
-		std::cout << "Warning : Player::setDirection passed out of range direction " << 
-			direction << " - ignoring" << std::endl;
+		WARN("Player::setDirection passed out of range direction " <<
+			direction << " - ignoring");
 		return;
 	}
 	double k;
-		
+
 	//
 	// If we are tackling, we can't do anything else until we've finished sliding!
 	//
@@ -406,12 +427,12 @@ void Player::setDirection(int direction)
 			m_justTurned=true;
 		}
 		m_direction=direction;
-			
+
 		k = moveSpeed(m_move);
 		if(m_touchTimer!=0) k*= Player::moveSlowdown;
-	
+
 		Point3D newVelocity = dirVal[m_direction]*k;
-	
+
 		// Player "guidance" so that it is easy to connect with the ball. If the player is slightly
 		// off line, he will be moved on line, so you don't have to press as many diagonals to hit
 		// the ball. Subtle, but effective.
@@ -420,15 +441,15 @@ void Player::setDirection(int direction)
 				(position() - m_ball->position()).length() ) {
 				Point3D left = Matrix::rollTransform(-0.174539252) * dirVal[m_direction];
 				Point3D right= Matrix::rollTransform(0.174539252) * dirVal[m_direction];
-			
+
 				if( (m_ball->position() - position()).liesWithinArc(left, right)) {
 					newVelocity = (m_ball->position() -
 						       		position()).setZ(0).normalise() * k;
 				}
 			}
 		}
-		
-		setVelocity(newVelocity);	
+
+		setVelocity(newVelocity);
 	}
 }
 
@@ -479,7 +500,7 @@ int Player::closestDirection(const Point3D &pos)
 	Point3D newDist;
 	int dir = 0;
 	double currentLength = (position() - pos).length();
-	
+
 	m_directionCount=0;
 	for(int count=0; count<8; count++) {
 		newDist = position() + (dirVal[count] * 0.01) - pos;
@@ -488,7 +509,7 @@ int Player::closestDirection(const Point3D &pos)
 			currentLength = newDist.length();
 		}
 	}
-	
+
 	return dir;
 }
 
@@ -498,12 +519,12 @@ bool Player::committedToMove()
 	// Shooting/passing takes time!
 	// If we are tackling, we can't do anything else until we've finished sliding!
 	//
-	
+
 	return m_commitTime>0;
-}	
+}
 
 bool Player::applyAftertouch(int direction)
-{	
+{
 	if(!m_kickCountdown) return false;
 
 
@@ -515,16 +536,16 @@ bool Player::applyAftertouch(int direction)
 		m_kickCountdown = 0;
 		return false;   // an upwards moving ball does not have aftertouch applied.
 	}
-	ubv *= 1.0 / sqrt(ubv.length());		
-	
+	ubv *= 1.0 / sqrt(ubv.length());
+
 	// Determine unit vector perpendicular to the ball direction.
 	ubv = Matrix::rollTransform(1.570796327) * ubv;
-		
+
 
 	// Rotate direction vector by so many radians around the direction vector.
 	Point3D udv = dirVal[direction];
 	udv = Matrix::arbitraryTransform(ubv, 1.2) * udv;
-	
+
 	m_ball->accelerate(udv * 0.07);
 
 	return true;
@@ -533,9 +554,9 @@ bool Player::applyAftertouch(int direction)
 bool Player::touchingBall(bool shooting)
 {
 	if((controlState() == Full) || (controlState() == KickOnly)) {
-		double len = (m_ball->position() - position()).length();	
+		double len = (m_ball->position() - position()).length();
 		if(m_ball->position().z() < kickHeight) {
-			if( (justTurned() && len < cornerControl) || 
+			if( (justTurned() && len < cornerControl) ||
 			    (len < lineControl) || (shooting && len < shootControl)) {
 				return true;
 			}
@@ -560,7 +581,7 @@ int Player::currentKickPriority()
 	return priority;
 }
 
-void Player::tryTrapBall() 
+void Player::tryTrapBall()
 {
 	/* This code lets a player trap the ball. */
 	Point3D groundVel = velocity();
@@ -585,7 +606,7 @@ void Player::tryTrapBall()
 
 					if( sqrt((reqvel - m_ball->velocity()).length()) / sqrt(m_ball->velocity().length()) > 0.05) {
 						m_ball->kickBall(reqvel,
-							currentKickPriority(), 
+							currentKickPriority(),
 							this);
 						m_touchTimer = 100;
 					}
@@ -612,7 +633,8 @@ double Player::moveSpeed(Moves move)
 		case Pass	:	return m_runSpeed;
 		case Shoot	:	return m_runSpeed;
 		case Header	:	return m_runSpeed * 2;
-		default		:	std::cout << "Warning - moveSpeed() asked for unknown move" << std::endl;
+		case FallOver: // TODO
+		default		:	WARN("moveSpeed() asked for unknown move");
 					return m_runSpeed;
 	}
 }
@@ -632,7 +654,7 @@ bool Player::hasBall()
 	if(!isActive()) return false;
 	if(GameEngine::lastPlayerTouch() != this) return false;
 	if(m_touchTimer == 0) return false;
-	
+
 	return true;
 }
 
@@ -650,7 +672,7 @@ void Player::moveToDesiredPosition()
 	if(currentLength < m_limpSpeed*m_limpSpeed) {
 		setMove(Stand);
 		setDirection(closestDirection(m_ball->position()));
-	} else {	
+	} else {
 		newDist += dirVal[m_direction] * m_limpSpeed;
 		newDist -= m_desiredPosition;
 
@@ -693,9 +715,9 @@ void Player::moveGoalkeeper()
 			wantToBe = m_desiredPosition+vector;
 		}
 	}
-	
+
 	Point3D curDist = position() - wantToBe;
-			
+
 	if(curDist.length() < m_limpSpeed*m_limpSpeed) {
 		setMove(Stand);
 		setDirection(closestDirection(m_ball->position()));
