@@ -1,19 +1,22 @@
 /***************************************************************************
-                          player.cpp  - Encapsulates a football player, and
-						  				all associated logic.
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
 #ifndef TUXFOOTBALL_PLAYER
@@ -33,6 +36,7 @@ class Pitch;
 class Team;
 class GameEngine;
 
+/** Encapsulates a football player, and all associated logic. */
 class Player : public Body {
 public:
 	static Point3D dirVal[8];
@@ -158,7 +162,7 @@ class PlayerContainer {
 public:
 	PlayerContainer()
 	{
-		m_player = NULL;
+		m_player = 0;
 	}
 
 	PlayerContainer(const PlayerContainer &cont) 
@@ -173,14 +177,14 @@ public:
 	}
 	
 	~PlayerContainer() {
-		if(m_player!= NULL) {
+		if(m_player!= 0) {
 			m_player->freeReference();
 		}
 	}
 
 	PlayerContainer &operator=(PlayerContainer &cont) {
 		m_player = *cont;
-		if(m_player!=NULL) {
+		if(m_player!=0) {
 			m_player->addReference();
 		}
 		return *this;
