@@ -1,33 +1,42 @@
 /***************************************************************************
-                          team.cpp  - Handles team-based logic.
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "team.h"
-#include "gameengine.h"
-#include "matrix.h"
 
 #include <string>
 #include <iostream>
 
+#include "gameengine.h"
+#include "matrix.h"
+
 Team::Team(GameEngine *gameEngine, std::string name, std::string shortname, std::string skin, std::string playerMarker, Pitch *pitch, Ball *ball, bool topHalf)
 {
 	m_name = name;
 	m_shortname = shortname;
-	m_firstPlayer = NULL;
-	m_secondPlayer = NULL;
+	m_firstPlayer = 0;
+	m_secondPlayer = 0;
 
 	m_ball = ball;
 
@@ -42,7 +51,7 @@ Team::Team(GameEngine *gameEngine, std::string name, std::string shortname, std:
 
 	m_pitch = pitch;
 	m_topHalf = topHalf;
-	m_activePlayer = NULL;
+	m_activePlayer = 0;
 
 	setFormation(4, 3, 3);
 	setupNationalAnthem();
@@ -80,6 +89,7 @@ void Team::update(void)
 	}
 
 	switch(controlState()) {
+		default:
 		case Player::None :
 			break;
 		case Player::KickOnly :
@@ -368,7 +378,7 @@ void Team::setActivePlayer(list<PlayerContainer>::iterator player)
 	}
 
 	if( player==m_players.end()) {
-		m_activePlayer = NULL;
+		m_activePlayer = 0;
 	} else {
 		m_activePlayer = (*(*player));
 	}
@@ -463,15 +473,15 @@ Player *Team::calculateClosestPlayers(Point3D point)
 	double flen = 0;
 	double slen = 0;
 
-	m_firstPlayer = NULL;
-	m_secondPlayer = NULL;
+	m_firstPlayer = 0;
+	m_secondPlayer = 0;
 
 	std::list<PlayerContainer>::iterator itt;
 
 	for(itt = m_players.begin(); itt!=m_players.end(); ++itt) {
 		double testlen = (*(*itt))->distanceFrom(point);
 
-		if(m_firstPlayer==NULL) {
+		if(m_firstPlayer==0) {
 			m_firstPlayer = (*(*itt));
 			flen = testlen;
 		} else 	if(testlen < flen) {
@@ -479,7 +489,7 @@ Player *Team::calculateClosestPlayers(Point3D point)
 			slen = flen;
 			m_firstPlayer = (*(*itt));
 			flen = testlen;
-		} else if(m_secondPlayer == NULL) {
+		} else if(m_secondPlayer == 0) {
 			m_secondPlayer = (*(*itt));
 			slen = testlen;
 		} else if(testlen < slen) {
