@@ -1,40 +1,44 @@
 /***************************************************************************
-                          tilemap.cpp  - Draws "tiles". A tile map specifies
-						  				a number of bitmap images, and then
-										a grid specifying where each of those
-										images should be placed. This allows
-										for efficient management of large images
-										with small amounts of unique detail - for
-										instance, with pitch lines.
-                             -------------------
-    begin                : 18.04.2003
-    copyright            : (C) 2003 by Jason Wood
-    email                : jasonwood@blueyonder.co.uk
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2003-2011 by Tux Football development team              *
+ *   Authors: Jason Wood <jasonwood@blueyonder.co.uk>                      *
+ *            Christoph Brill <egore911@egore911.de>                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "tilemap.h"
+
 #include <iostream>
 #include <string>
 #include <fstream>
 #include <sstream>
-#include "surfacemanager.h"
+
+#include "resources/surfacemanager.h"
 #include "const.h"
+#include "logger/logger.h"
 
 TileMap::TileMap(SDL_Surface *screen, std::string path)
 {
 	m_screen = screen;
 
 	std::ifstream tilemap;
-	int data_dirs = sizeof(data_dir)/sizeof(std::string);
 	for (int i = 0; i < data_dirs; i++) {
 		std::string datadir = std::string(data_dir[i]);
 		datadir.append("/");
@@ -45,15 +49,15 @@ TileMap::TileMap(SDL_Surface *screen, std::string path)
 	}
 
 	if(!tilemap.good()) {
-		std::cout << "Error - tile.map not found in " << path << std::endl;
+		WARN("tile.map not found in " << path);
 		return;
 	}
 
-	std::cout << "FIXME - tilesize fixed at 16X16" << std::endl;
+	WARN("FIXME - tilesize fixed at 16X16");
 	m_tileWidth = 16;
 	m_tileHeight = 16;
 
-	std::cout << "FIXME - tilemap size fixed at 2560 * 4096 for the moment" << std::endl;
+	WARN("FIXME - tilemap size fixed at 2560 * 4096 for the moment");
 	m_tileMapWidth = 2560;
 	m_tileMapHeight = 4096;
 
@@ -132,7 +136,7 @@ void TileMap::draw(int left, int top)
 
 			if(surf) {
 				if(SDL_BlitSurface(surf, &tr, m_screen, &sr) < 0) {
-					std::cerr << "Error - could not pitch tile : " << SDL_GetError() << std::endl;
+					ERROR("could not pitch tile : " << SDL_GetError());
 				}
 			}
 		}
@@ -165,6 +169,6 @@ bool TileMap::isWhiteSpace(char val)
 		case ',' :
 		case ' ' :
 		case '\n' : return true;
+		default: return false;
 	}
-	return false;
 }
